@@ -1,9 +1,9 @@
 # -*- coding: utf-8 -*-
 
 from __future__ import with_statement
+
+from recoder.pyver import *
 import json
-import urllib
-import HTMLParser
 
 __all__ = ['BaseRecoder']
 
@@ -16,15 +16,16 @@ class BaseRecoder(object):
     codings = None
 
     funcs = [
-        [lambda *args, **kwargs: kwargs['text'].encode(kwargs['coding'], errors=kwargs['errors']), True, (unicode,)],
-        [lambda *args, **kwargs: kwargs['text'].decode(kwargs['coding'], errors=kwargs['errors']), True, (str,)],
-        [lambda *args, **kwargs: urllib.unquote_plus(kwargs['text']), False, (str,)],
-        [lambda *args, **kwargs: urllib.unquote_plus(kwargs['text'].replace('=', '%')), False, (str,)],
-        [lambda *args, **kwargs: html_parser.unescape(kwargs['text']), False, (unicode,)],
+        [lambda *args, **kwargs: kwargs['text'].encode(kwargs['coding'], errors=kwargs['errors']), True, (unicode_type,)],
+        [lambda *args, **kwargs: kwargs['text'].decode(kwargs['coding'], errors=kwargs['errors']), True, (encoded_type,)],
+        [lambda *args, **kwargs: unquote_plus(kwargs['text']), False, (encoded_type,)],
+        [lambda *args, **kwargs: unquote_plus(kwargs['text'].replace('=', '%')), False, (encoded_type,)],
+        [lambda *args, **kwargs: html_parser.unescape(kwargs['text']), False, (unicode_type,)],
     ]
 
     regular_error_classes = (
         UnicodeError,
+        AttributeError,  # for py3 support
     )
 
     def __init__(self, depth=2, errors='ignore', use_plus_words=False):
@@ -41,7 +42,7 @@ class BaseRecoder(object):
 
     def _contains_plus_word(self, text):
         for word in self.plus_words:
-            if (u' ' + word + u' ') in text:
+            if (' ' + word + ' ') in text:
                 return True
         return False
 
@@ -63,7 +64,8 @@ class BaseRecoder(object):
     def _calc_weight(self, text):
         weight = 0.0
         count = 0
-        for i in xrange(len(text) - 2):
+
+        for i in range_iterator(len(text) - 2):
             gram = text[i:i+3]
             weight += self.grams.get(gram, 0.0)
             count += 1
@@ -73,7 +75,7 @@ class BaseRecoder(object):
         max_weight = self._calc_weight(unicode_text.lower())
         max_text = unicode_text
         for fixed_text, transform in self._iter(unicode_text, self.depth):
-            if not isinstance(fixed_text, unicode):
+            if not isinstance(fixed_text, unicode_type):
                 continue
             fixed_text = fixed_text.lower()
             weight = self._calc_weight(fixed_text)
@@ -97,6 +99,6 @@ class BaseRecoder(object):
                         max_weight = weight
                         max_text = unicode_text.encode(ce, errors=self.errors).decode(cd, errors=self.errors)
                         self.last_transform = lambda text: text.encode(ce, errors=self.errors).decode(cd, errors=self.errors)
-                except UnicodeError:
+                except self.regular_error_classes:
                     pass
         return max_text
