@@ -4,10 +4,16 @@ from __future__ import with_statement
 
 import sys
 import json
-from .builder import Builder
+from recoder.builder.builder import Builder
+from recoder.pyver import *
 
 coding = sys.argv[1] if len(sys.argv) > 1 else 'utf-8'
-input_data = sys.stdin.read().decode(coding, errors='ignore')
+
+if pyver == 2:
+    input_data = sys.stdin.read().decode(coding, errors='ignore')
+elif pyver == 3:
+    input_data = sys.stdin.buffer.read().decode(coding, errors='ignore')
+
 builder = Builder()
 
 with open('3grams.json', 'w') as f:
