@@ -22,5 +22,6 @@ class Recoder(BaseRecoder):
         'iso8859-5',
         'iso8859-9',
         'cp866',
-        'maccyrillic'
+        'maccyrillic',
+        'gb2312'
     ]
\ No newline at end of file
