@@ -1,10 +1,15 @@
 # -*- coding: utf-8 -*-
 
 import unittest
-import cyrillic
+from recoder import cyrillic
+from recoder.pyver import *
 
 class TestMain(unittest.TestCase):
-    sample_text = u'какой-то текст для примера работы библиотеки'
+    if pyver == 2:
+        sample_text = 'какой-то текст для примера работы библиотеки'.decode('utf-8')
+    elif pyver == 3:
+        sample_text = 'какой-то текст для примера работы библиотеки'
+
     cyr_recoder = cyrillic.Recoder()
 
     def test_cyrillic_cp1251_koi8r(self):
